==> python-sparse_0.16.0a9.orig.tar.gz: sparse-0.16.0a9/sparse/numba_backend/__init__.py <==
from numpy import (
    add,
    bitwise_and,
    bitwise_not,
    bitwise_or,
    bitwise_xor,
    can_cast,
    ceil,
    complex64,
    complex128,
    conj,
    cos,
    cosh,
    divide,
    e,
    exp,
    expm1,
    finfo,
    float16,
    float32,
    float64,
    floor,
    floor_divide,
    greater,
    greater_equal,
    iinfo,
    inf,
    int8,
    int16,
    int32,
    int64,
    isfinite,
    less,
    less_equal,
    log,
    log1p,
    log2,
    log10,
    logaddexp,
    logical_and,
    logical_not,
    logical_or,
    logical_xor,
    multiply,
    nan,
    negative,
    newaxis,
    not_equal,
    pi,
    positive,
    remainder,
    sign,
    sin,
    sinh,
    sqrt,
    square,
    subtract,
    tan,
    tanh,
    trunc,
    uint8,
    uint16,
    uint32,
    uint64,
)
from numpy import arccos as acos
from numpy import arccosh as acosh
from numpy import arcsin as asin
from numpy import arcsinh as asinh
from numpy import arctan as atan
from numpy import arctan2 as atan2
from numpy import arctanh as atanh
from numpy import bool_ as bool
from numpy import invert as bitwise_invert
from numpy import left_shift as bitwise_left_shift
from numpy import power as pow
from numpy import right_shift as bitwise_right_shift

from ._common import (
    SparseArray,
    abs,
    all,
    any,
    asarray,
    asnumpy,
    astype,
    broadcast_arrays,
    broadcast_to,
    concat,
    concatenate,
    dot,
    einsum,
    empty,
    empty_like,
    equal,
    eye,
    full,
    full_like,
    imag,
    isinf,
    isnan,
    matmul,
    max,
    mean,
    min,
    moveaxis,
    nonzero,
    ones,
    ones_like,
    outer,
    pad,
    permute_dims,
    prod,
    real,
    reshape,
    round,
    squeeze,
    stack,
    std,
    sum,
    tensordot,
    var,
    vecdot,
    zeros,
    zeros_like,
)
from ._compressed import GCXS
from ._coo import COO, as_coo
from ._coo.common import (
    argmax,
    argmin,
    argwhere,
    asCOO,
    clip,
    diagonal,
    diagonalize,
    expand_dims,
    flip,
    isneginf,
    isposinf,
    kron,
    matrix_transpose,
    nanmax,
    nanmean,
    nanmin,
    nanprod,
    nanreduce,
    nansum,
    result_type,
    roll,
    sort,
    take,
    tril,
    triu,
    unique_counts,
    unique_values,
    where,
)
from ._dok import DOK
from ._io import load_npz, save_npz
from ._umath import elemwise
from ._utils import random

__all__ = [
    "COO",
    "DOK",
    "GCXS",
    "SparseArray",
    "abs",
    "acos",
    "acosh",
    "add",
    "all",
    "any",
    "argmax",
    "argmin",
    "argwhere",
    "asCOO",
    "as_coo",
    "asarray",
    "asin",
    "asinh",
    "asnumpy",
    "astype",
    "atan",
    "atan2",
    "atanh",
    "bitwise_and",
    "bitwise_invert",
    "bitwise_left_shift",
    "bitwise_not",
    "bitwise_or",
    "bitwise_right_shift",
    "bitwise_xor",
    "bool",
    "broadcast_arrays",
    "broadcast_to",
    "can_cast",
    "ceil",
    "clip",
    "complex128",
    "complex64",
    "concat",
    "concatenate",
    "conj",
    "cos",
    "cosh",
    "diagonal",
    "diagonalize",
    "divide",
    "dot",
    "e",
    "einsum",
    "elemwise",
    "empty",
    "empty_like",
    "equal",
    "exp",
    "expand_dims",
    "expm1",
    "eye",
    "finfo",
    "flip",
    "float16",
    "float32",
    "float64",
    "floor",
    "floor_divide",
    "full",
    "full_like",
    "greater",
    "greater_equal",
    "iinfo",
    "imag",
    "inf",
    "int16",
    "int32",
    "int64",
    "int8",
    "isfinite",
    "isinf",
    "isnan",
    "isneginf",
    "isposinf",
    "kron",
    "less",
    "less_equal",
    "load_npz",
    "log",
    "log10",
    "log1p",
    "log2",
    "logaddexp",
    "logical_and",
    "logical_not",
    "logical_or",
    "logical_xor",
    "matmul",
    "matrix_transpose",
    "max",
    "mean",
    "min",
    "moveaxis",
    "multiply",
    "nan",
    "nanmax",
    "nanmean",
    "nanmin",
    "nanprod",
    "nanreduce",
    "nansum",
    "negative",
    "newaxis",
    "nonzero",
    "not_equal",
    "ones",
    "ones_like",
    "outer",
    "pad",
    "permute_dims",
    "pi",
    "positive",
    "pow",
    "prod",
    "random",
    "real",
    "remainder",
    "reshape",
    "result_type",
    "roll",
    "round",
    "save_npz",
    "sign",
    "sin",
    "sinh",
    "sort",
    "sqrt",
    "square",
    "squeeze",
    "stack",
    "std",
    "subtract",
    "sum",
    "take",
    "tan",
    "tanh",
    "tensordot",
    "tril",
    "triu",
    "trunc",
    "uint16",
    "uint32",
    "uint64",
    "uint8",
    "unique_counts",
    "unique_values",
    "var",
    "vecdot",
    "where",
    "zeros",
    "zeros_like",
]

==> python-sparse_0.17.0.orig.tar.gz: sparse-0.17.0/sparse/numba_backend/__init__.py <==
from numpy import (
    add,
    bitwise_and,
    bitwise_not,
    bitwise_or,
    bitwise_xor,
    ceil,
    complex64,
    complex128,
    conj,
    copysign,
    cos,
    cosh,
    divide,
    e,
    exp,
    expm1,
    finfo,
    float16,
    float32,
    float64,
    floor,
    floor_divide,
    greater,
    greater_equal,
    hypot,
    iinfo,
    inf,
    int8,
    int16,
    int32,
    int64,
    isfinite,
    less,
    less_equal,
    log,
    log1p,
    log2,
    log10,
    logaddexp,
    logical_and,
    logical_not,
    logical_or,
    logical_xor,
    maximum,
    minimum,
    multiply,
    nan,
    negative,
    newaxis,
    nextafter,
    not_equal,
    pi,
    positive,
    reciprocal,
    remainder,
    sign,
    signbit,
    sin,
    sinh,
    sqrt,
    square,
    subtract,
    tan,
    tanh,
    trunc,
    uint8,
    uint16,
    uint32,
    uint64,
)
from numpy import arccos as acos
from numpy import arccosh as acosh
from numpy import arcsin as asin
from numpy import arcsinh as asinh
from numpy import arctan as atan
from numpy import arctan2 as atan2
from numpy import arctanh as atanh
from numpy import bool_ as bool
from numpy import invert as bitwise_invert
from numpy import left_shift as bitwise_left_shift
from numpy import power as pow
from numpy import right_shift as bitwise_right_shift

from ._common import (
    SparseArray,
    abs,
    all,
    any,
    asarray,
    asnumpy,
    astype,
    broadcast_arrays,
    broadcast_to,
    can_cast,
    concat,
    concatenate,
    dot,
    einsum,
    empty,
    empty_like,
    equal,
    eye,
    full,
    full_like,
    imag,
    isinf,
    isnan,
    matmul,
    max,
    mean,
    min,
    moveaxis,
    nonzero,
    ones,
    ones_like,
    outer,
    pad,
    permute_dims,
    prod,
    real,
    reshape,
    round,
    squeeze,
    stack,
    std,
    sum,
    tensordot,
    var,
    vecdot,
    zeros,
    zeros_like,
)
from ._compressed import GCXS
from ._coo import COO, as_coo
from ._coo.common import (
    argmax,
    argmin,
    argwhere,
    asCOO,
    clip,
    diagonal,
    diagonalize,
    expand_dims,
    flip,
    isneginf,
    isposinf,
    kron,
    matrix_transpose,
    nanmax,
    nanmean,
    nanmin,
    nanprod,
    nanreduce,
    nansum,
    result_type,
    roll,
    sort,
    take,
    tril,
    triu,
    unique_counts,
    unique_values,
    where,
)
from ._dok import DOK
from ._io import load_npz, save_npz
from ._settings import IS_NUMPY2 as _IS_NUMPY2
from ._settings import __array_namespace_info__  # noqa: F401
from ._umath import elemwise
from ._utils import random

__all__ = [
    "COO",
    "DOK",
    "GCXS",
    "SparseArray",
    "abs",
    "acos",
    "acosh",
    "add",
    "all",
    "any",
    "argmax",
    "argmin",
    "argwhere",
    "asCOO",
    "as_coo",
    "asarray",
    "asin",
    "asinh",
    "asnumpy",
    "astype",
    "atan",
    "atan2",
    "atanh",
    "bitwise_and",
    "bitwise_invert",
    "bitwise_left_shift",
    "bitwise_not",
    "bitwise_or",
    "bitwise_right_shift",
    "bitwise_xor",
    "bool",
    "broadcast_arrays",
    "broadcast_to",
    "can_cast",
    "ceil",
    "clip",
    "complex128",
    "complex64",
    "concat",
    "concatenate",
    "conj",
    "copysign",
    "cos",
    "cosh",
    "diagonal",
    "diagonalize",
    "divide",
    "dot",
    "e",
    "einsum",
    "elemwise",
    "empty",
    "empty_like",
    "equal",
    "exp",
    "expand_dims",
    "expm1",
    "eye",
    "finfo",
    "flip",
    "float16",
    "float32",
    "float64",
    "floor",
    "floor_divide",
    "full",
    "full_like",
    "greater",
    "greater_equal",
    "hypot",
    "iinfo",
    "imag",
    "inf",
    "int16",
    "int32",
    "int64",
    "int8",
    "isfinite",
    "isinf",
    "isnan",
    "isneginf",
    "isposinf",
    "kron",
    "less",
    "less_equal",
    "load_npz",
    "log",
    "log10",
    "log1p",
    "log2",
    "logaddexp",
    "logical_and",
    "logical_not",
    "logical_or",
    "logical_xor",
    "matmul",
    "matrix_transpose",
    "max",
    "maximum",
    "mean",
    "min",
    "minimum",
    "moveaxis",
    "multiply",
    "nan",
    "nanmax",
    "nanmean",
    "nanmin",
    "nanprod",
    "nanreduce",
    "nansum",
    "negative",
    "newaxis",
    "nextafter",
    "nonzero",
    "not_equal",
    "ones",
    "ones_like",
    "outer",
    "pad",
    "permute_dims",
    "pi",
    "positive",
    "pow",
    "prod",
    "random",
    "real",
    "reciprocal",
    "remainder",
    "reshape",
    "result_type",
    "roll",
    "round",
    "save_npz",
    "sign",
    "signbit",
    "sin",
    "sinh",
    "sort",
    "sqrt",
    "square",
    "squeeze",
    "stack",
    "std",
    "subtract",
    "sum",
    "take",
    "tan",
    "tanh",
    "tensordot",
    "tril",
    "triu",
    "trunc",
    "uint16",
    "uint32",
    "uint64",
    "uint8",
    "unique_counts",
    "unique_values",
    "var",
    "vecdot",
    "where",
    "zeros",
    "zeros_like",
]


if _IS_NUMPY2:
    from numpy import isdtype

    __all__ += [
        "isdtype",
    ]

__all__.sort()
